==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Homepagina',
	'article' => 'Artikel',
	'articles' => 'Artikelen',
	'articles_auteur' => 'Artikelen van deze auteur',
	'articles_populaires' => 'Meest bekeken artikelen',
	'articles_rubrique' => 'Artikelen in deze rubriek',
	'aucun_article' => 'Op dit adres is geen artikel te vinden',
	'aucun_auteur' => 'Op dit adres is geen auteur te vinden',
	'aucun_site' => 'Op dit adres is geen site te vinden',
	'aucune_breve' => 'Op dit adres is geen nieuwsflits te vinden',
	'aucune_rubrique' => 'Op dit adres is geen rubriek te vinden',
	'auteur' => 'Auteur',
	'autres' => 'Anderen',
	'autres_breves' => 'Andere nieuwsflitsen',
	'autres_groupes_mots_clefs' => 'Andere groepen trefwoorden',
	'autres_sites' => 'Andere sites',

	// B
	'bonjour' => 'Hallo',

	// C
	'commenter_site' => 'Reageren op de site',
	'contact' => 'Contact',
	'copie_document_impossible' => 'Het is niet mogelijk het document te kopiëren',

	// D
	'date' => 'Datum',
	'dernier_ajout' => 'Laatste toevoeging',
	'dernieres_breves' => 'Laatste nieuwsflitsen',
	'derniers_articles' => 'Laatste artikelen',
	'derniers_commentaires' => 'Laatste commentaren',
	'derniers_messages_forum' => 'Laatst gepubliceerde berichten in het forum',

	// E
	'edition_mode_texte' => 'Uitgave in tekstmodus van',
	'en_reponse' => 'Als antwoord op:',
	'en_resume' => 'Samengevat',
	'envoyer_message' => 'Een bericht sturen',
	'espace_prive' => 'Privé gedeelte',

	// F
	'formats_acceptes' => 'Toegelaten formaten: @formats@.',

	// H
	'hierarchie_site' => 'Structuur van de site',

	// J
	'jours' => 'dagen',

	// L
	'lien_connecter' => 'Aanmelden',

	// M
	'meme_auteur' => 'Van dezelfde auteur',
	'meme_rubrique' => 'In dezelfde rubriek',
	'memes_auteurs' => 'Van dezelfde auteurs',
	'message' => 'Bericht',
	'messages_forum' => 'Berichten',
	'messages_recents' => 'Meest recente forumberichten',
	'mots_clef' => 'Trefwoord',
	'mots_clefs' => 'Trefwoorden',
	'mots_clefs_meme_groupe' => 'Trefwoorden van dezelfde groep',

	// N
	'navigation' => 'Navigatie',
	'nom' => 'Naam',
	'nouveautes' => 'Nieuwigheden',
	'nouveautes_web' => 'Nieuwigheden op het Web',
	'nouveaux_articles' => 'Nieuwe artikelen',
	'nouvelles_breves' => 'Nieuwe nieuwsflitsen',

	// P
	'page_precedente' => 'vorige pagina',
	'page_suivante' => 'volgende pagina',
	'par_auteur' => 'door ',
	'participer_site' => 'Wanneer je je hieronder inschrijft, kun je zelf een bijdrage leveren aan deze site door je eigen artikelen voor te stellen. Je ontvangt meteen een e-mail met daarin de toegangscode voor het privé-gedeelte van de site.',
	'plan_site' => 'Overzicht van de site',
	'popularite' => 'Populariteit',
	'poster_message' => 'Een bericht plaatsen',
	'proposer_site' => 'Je kan voorstellen een site in deze rubriek op te nemen:',

	// R
	'repondre_article' => 'Dit artikel beantwoorden',
	'repondre_breve' => 'Op deze nieuwsflits reageren',
	'resultats_recherche' => 'Resultaten van de zoekopdracht',
	'retour_debut_forums' => 'Terug naar de startpagina van de forums',
	'rubrique' => 'Rubriek',
	'rubriques' => 'Rubrieken',

	// S
	'signatures_petition' => 'Ondertekeningen',
	'site_realise_avec_spip' => 'Site gebouwd met SPIP',
	'sites_web' => 'Websites',
	'sous_rubriques' => 'Subrubrieken',
	'spam' => 'Spam',
	'suite' => 'vervolg',
	'sur_web' => 'Op het web',
	'syndiquer_rubrique' => 'Nieuws overnemen uit deze rubriek',
	'syndiquer_site' => 'Nieuws overnemen van de hele site',

	// T
	'texte_lettre_information' => 'Dit is de nieuwsbrief van de site',
	'texte_lettre_information_2' => 'Deze nieuwsbrief toont de publicaties vanaf',

	// V
	'ver_imprimer' => 'Afdrukversie',
	'voir_en_ligne' => 'Online bekijken',
	'voir_squelette' => 'het skelet van deze bladzijde bekijken'
);

==> spip_4.4.7+dfsg.orig.tar.xz: ecrire/lang/public_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=nl
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Homepagina',
	'article' => 'Artikel',
	'articles' => 'Artikelen',
	'articles_auteur' => 'Artikelen van deze auteur',
	'articles_populaires' => 'Meest bekeken artikelen',
	'articles_rubrique' => 'Artikelen in deze rubriek',
	'aucun_article' => 'Op dit adres is geen artikel te vinden',
	'aucun_auteur' => 'Op dit adres is geen auteur te vinden',
	'aucun_site' => 'Op dit adres is geen site te vinden',
	'aucune_breve' => 'Op dit adres is geen nieuwsflits te vinden',
	'aucune_rubrique' => 'Op dit adres is geen rubriek te vinden',
	'auteur' => 'Auteur',
	'autres' => 'Anderen',
	'autres_breves' => 'Andere nieuwsflitsen',
	'autres_groupes_mots_clefs' => 'Andere groepen trefwoorden',
	'autres_sites' => 'Andere sites',

	// B
	'bonjour' => 'Hallo',

	// C
	'commenter_site' => 'Reageren op de site',
	'contact' => 'Contact',
	'copie_document_impossible' => 'Het is niet mogelijk het document te kopiëren',

	// D
	'date' => 'Datum',
	'dernier_ajout' => 'Laatste toevoeging',
	'dernieres_breves' => 'Laatste nieuwsflitsen',
	'derniers_articles' => 'Laatste artikelen',
	'derniers_commentaires' => 'Laatste commentaren',
	'derniers_messages_forum' => 'Laatst gepubliceerde berichten in het forum',

	// E
	'edition_mode_texte' => 'Uitgave in tekstmodus van',
	'en_reponse' => 'Als antwoord op:',
	'en_resume' => 'Samengevat',
	'envoyer_message' => 'Een bericht sturen',
	'espace_prive' => 'Privé gedeelte',

	// F
	'formats_acceptes' => 'Toegelaten formaten: @formats@.',

	// H
	'hierarchie_site' => 'Structuur van de site',

	// J
	'jours' => 'dagen',

	// L
	'lien_connecter' => 'Aanmelden',

	// M
	'meme_auteur' => 'Van dezelfde auteur',
	'meme_rubrique' => 'In dezelfde rubriek',
	'memes_auteurs' => 'Van dezelfde auteurs',
	'message' => 'Bericht',
	'messages_forum' => 'Berichten',
	'messages_recents' => 'Meest recente forumberichten',
	'mots_clef' => 'Trefwoord',
	'mots_clefs' => 'Trefwoorden',
	'mots_clefs_meme_groupe' => 'Trefwoorden van dezelfde groep',

	// N
	'navigation' => 'Navigatie',
	'nom' => 'Naam',
	'nouveautes' => 'Nieuwigheden',
	'nouveautes_web' => 'Nieuwigheden op het Web',
	'nouveaux_articles' => 'Nieuwe artikelen',
	'nouvelles_breves' => 'Nieuwe nieuwsflitsen',

	// P
	'page_precedente' => 'vorige pagina',
	'page_suivante' => 'volgende pagina',
	'par_auteur' => 'door ',
	'participer_site' => 'Wanneer je je hieronder inschrijft, kun je zelf een bijdrage leveren aan deze site door je eigen artikelen voor te stellen. Je ontvangt meteen een e-mail met daarin de toegangscode voor het privé-gedeelte van de site.',
	'plan_site' => 'Overzicht van de site',
	'popularite' => 'Populariteit',
	'poster_message' => 'Een bericht plaatsen',
	'proposer_site' => 'Je kan voorstellen een site in deze rubriek op te nemen:',

	// R
	'repondre_article' => 'Dit artikel beantwoorden',
	'repondre_breve' => 'Op deze nieuwsflits reageren',
	'resultats_recherche' => 'Resultaten van de zoekopdracht',
	'retour_debut_forums' => 'Terug naar de startpagina van de forums',
	'rubrique' => 'Rubriek',
	'rubriques' => 'Rubrieken',

	// S
	'signatures_petition' => 'Ondertekeningen',
	'site_realise_avec_spip' => 'Site gebouwd met SPIP',
	'sites_web' => 'Websites',
	'sous_rubriques' => 'Subrubrieken',
	'spam' => 'Spam',
	'suite' => 'vervolg',
	'sur_web' => 'Op het web',
	'syndiquer_rubrique' => 'Nieuws overnemen uit deze rubriek',
	'syndiquer_site' => 'Nieuws overnemen van de hele site',

	// T
	'texte_lettre_information' => 'Dit is de nieuwsbrief van de site',
	'texte_lettre_information_2' => 'Deze nieuwsbrief toont de publicaties vanaf',

	// V
	'ver_imprimer' => 'Afdrukversie',
	'voir_en_ligne' => 'Online bekijken',
	'voir_squelette' => 'het skelet van deze bladzijde bekijken',
];
